package at.ac.tuwien.sepm.assignment.individual.persistence;

import at.ac.tuwien.sepm.assignment.individual.entity.Owner;
import at.ac.tuwien.sepm.assignment.individual.exception.NotFoundException;
import org.springframework.dao.DataAccessException;

import java.io.IOException;

public interface OwnerDao {

    /**
     * @param id of the owner to find.
     * @return the owner with the specified id.
     * @throws DataAccessException will be thrown if something goes wrong during the database access.
     * @throws NotFoundException   will be thrown if the owner could not be found in the database.
     */
    Owner findOneById(Long id);

    /**
     * @param owner that specifies the owner to add
     * @return the newly created owner
     * @throws DataAccessException will be thrown if something goes wrong during the database access.
     */
    Owner addOwner(Owner owner);

    /**
     * @param owner that specifies the new owner values alongside with the id of the owner to update
     * @return the updated owner
     * @throws DataAccessException will be thrown if something goes wrong during the database access.
     */
    Owner updateOwner(Owner owner) throws DataAccessException;

    /**
     * @param id of the owner to delete
     * @throws DataAccessException will be thrown if something goes wrong during the database access.
     * @throws NotFoundException   will be thrown if the owner could not be found in the database.
     */
    void deleteOwner(Long id) throws DataAccessException, NotFoundException;
}
