import {Injectable} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {Globals} from '../global/globals';
import {Observable} from 'rxjs';
import {Owner} from '../dto/owner';

@Injectable({
  providedIn: 'root'
})
export class OwnerService {

  private messageBaseUri: string = this.globals.backendUri + '/owners';

  constructor(private httpClient: HttpClient, private globals: Globals) {
  }

  /**
   * Loads specific owner from the backend
   * @param id of owner to load
   */
  getOwnerById(id: number): Observable<Owner> {
    console.log('Load owner details for ' + id);
    return this.httpClient.get<Owner>(this.messageBaseUri + '/' + id);
  }

  /**
   * Adds a specific owner to the backend and loads it if successful
   * @param owner
   */
  addOwner(owner: Owner): Observable<Owner> {
    console.log('Add new owner ' + JSON.stringify(owner));
    return this.httpClient.post<Owner>(this.messageBaseUri, owner);
  }

  /**
   * Update a specific owner with the supplied values
   * @param owner
   */
  updateOwner(owner: Owner): Observable<Owner> {
    console.log('Update owner with id ' + owner.id + ': '+ JSON.stringify(owner));
    return this.httpClient.put<Owner>(this.messageBaseUri + '/' + owner.id, owner);
  }
}
